@@ -29,13 +29,19 @@ class SStrChar:
     """
 
     def __init__(
-        self, text: str, table_node: str, column_node: Optional[str] = None, op_type: Optional[OperationType] = None
+        self,
+        text: str,
+        table_node: str,
+        column_node: Optional[str] = None,
+        op_type: Optional[OperationType] = None,
+        is_table: bool = False,
     ):
         self.ori_label = text
         self.text: str = text
         self.table_node: str = table_node
         self.column_node: Optional[str] = column_node
         self.op_type: Optional[OperationType] = op_type
+        self.is_table: bool = is_table
 
     def __str__(self):
         return self.text
@@ -44,6 +50,8 @@ class SStrChar:
         return len(self.text)
 
     def __hash__(self):
+        if self.is_table:
+            return hash((self.text, self.table_node))
         return hash((self.text, self.table_node, self.column_node))
 
     def __eq__(self, other):
@@ -51,7 +59,7 @@ class SStrChar:
             return (
                 self.text == other.text
                 and self.table_node == other.table_node
-                and self.column_node == other.column_node
+                and ((self.is_table and other.is_table) or self.column_node == other.column_node)
             )
         return False
 
@@ -66,7 +74,7 @@ class SStrChar:
         return (
             self.ori_label == other.ori_label
             and remove_number_in_string(self.table_node) == remove_number_in_string(other.table_node)
-            and remove_number_in_string(self.column_node) == remove_number_in_string(other.column_node)
+            and ((self.is_table and other.is_table) or remove_number_in_string(self.column_node) == remove_number_in_string(other.column_node))
         )
 
     def add_prefix(self, prefix: str) -> None:
@@ -468,7 +476,9 @@ class StringBuilder:
     # Add sub-graphs
     def add_projection(self, relation: Node, attribute: Node, agg_func: Optional[str]) -> None:
         # Create SStr objects
-        rel_sstr = SStrChar(relation.label, relation.name, op_type=OperationType.Projection)
+        rel_sstr = SStrChar(
+            relation.label, relation.name, attribute.name, op_type=OperationType.Projection, is_table=True
+        )
         att_sstr = SStrChar(attribute.label, relation.name, attribute.name, op_type=OperationType.Projection)
         agg_sstr = (
             SStrChar(agg_func, relation.name, attribute.name, op_type=OperationType.Projection) if agg_func else None
@@ -485,8 +495,12 @@ class StringBuilder:
         operand_parent: Optional[Node] = None,
     ) -> None:
         # Create SStr objects
-        ref_sstr = SStrChar(reference_point.label, reference_point.name, op_type=OperationType.Selection)
-        rel_sstr = SStrChar(relation.label, relation.name, op_type=OperationType.Selection)
+        ref_sstr = SStrChar(
+            reference_point.label, reference_point.name, attribute.name, op_type=OperationType.Selection, is_table=True
+        )
+        rel_sstr = SStrChar(
+            relation.label, relation.name, attribute.name, op_type=OperationType.Selection, is_table=True
+        )
         att_sstr = SStrChar(attribute.label, relation.name, attribute.name, op_type=OperationType.Selection)
         op_sstr = SStrChar(op.label, relation.name, attribute.name, op_type=OperationType.Selection)
         # Handle different by operand type
@@ -503,7 +517,9 @@ class StringBuilder:
                 arg3 = operand.name
             operand_sstr = SStrChar(arg1, arg2, arg3, op_type=OperationType.Selection)
             operand_parent_sstr = (
-                SStrChar(operand_parent.label, operand_parent.name, op_type=OperationType.Selection)
+                SStrChar(
+                    operand_parent.label, operand_parent.name, arg3, op_type=OperationType.Selection, is_table=True
+                )
                 if operand_parent
                 else None
             )
@@ -513,16 +529,20 @@ class StringBuilder:
         self, reference_point: Node, relation1: Node, edge: str, relation2: Node, has_incoming_edge: bool
     ) -> None:
         # Create SStr objects
-        ref_sstr = SStrChar(reference_point.label, reference_point.name, op_type=OperationType.Selection)
-        rel1_sstr = SStrChar(relation1.label, relation1.name, op_type=OperationType.Selection)
+        ref_sstr = SStrChar(reference_point.label, reference_point.name, op_type=OperationType.Selection, is_table=True)
+        rel1_sstr = SStrChar(relation1.label, relation1.name, op_type=OperationType.Selection, is_table=True)
         edge_sstr = SStrChar(edge, relation1.name, relation2.name, op_type=OperationType.Selection)
-        rel2_sstr = SStrChar(relation2.label, relation2.name, op_type=OperationType.Selection)
+        rel2_sstr = SStrChar(relation2.label, relation2.name, op_type=OperationType.Selection, is_table=True)
         self.join_conditions.append((ref_sstr, rel1_sstr, edge_sstr, rel2_sstr, has_incoming_edge))
 
     def add_grouping(self, reference_point: Node, relation: Node, attribute: Node) -> None:
         # Create SStr objects
-        ref_sstr = SStrChar(reference_point.label, reference_point.name, op_type=OperationType.Grouping)
-        rel_sstr = SStrChar(relation.label, relation.name, op_type=OperationType.Grouping)
+        ref_sstr = SStrChar(
+            reference_point.label, reference_point.name, attribute.name, op_type=OperationType.Grouping, is_table=True
+        )
+        rel_sstr = SStrChar(
+            relation.label, relation.name, attribute.name, op_type=OperationType.Grouping, is_table=True
+        )
         att_sstr = SStrChar(attribute.label, relation.name, attribute.name, op_type=OperationType.Grouping)
         self.grouping.append((ref_sstr, rel_sstr, att_sstr))
 
@@ -530,8 +550,12 @@ class StringBuilder:
         self, reference_point: Node, relation: Node, attribute: Node, function: Node, edge: Predicate, value: Node
     ) -> None:
         # Create SStr objects
-        ref_sstr = SStrChar(reference_point.label, reference_point.name, op_type=OperationType.Selection)
-        rel_sstr = SStrChar(relation.label, relation.name, op_type=OperationType.Selection)
+        ref_sstr = SStrChar(
+            reference_point.label, reference_point.name, attribute.name, op_type=OperationType.Selection, is_table=True
+        )
+        rel_sstr = SStrChar(
+            relation.label, relation.name, attribute.name, op_type=OperationType.Selection, is_table=True
+        )
         att_sstr = SStrChar(attribute.label, relation.name, attribute.name, op_type=OperationType.Selection)
         func_sstr = SStrChar(function.label, relation.name, attribute.name, op_type=OperationType.Selection)
         edge_sstr = SStrChar(edge.label, relation.name, attribute.name, op_type=OperationType.Selection)
