@@ -292,9 +292,9 @@ class Query_graph(nx.DiGraph):
                 continue
             for neighbor in self.get_neighbors(r1):
                 # If not join and the number of non visited relation is greater than 1
-                num_of_relations_to_visit = self.number_of_non_visited_relation_nodes(r1, set([neighbor]))
+                num_of_relations_to_visit = self.number_of_non_visited_relation_nodes(neighbor, set([r1]))
                 is_join = type(self.get_edge(r1, neighbor)) == Join
-                if not is_join and num_of_relations_to_visit > 1:
+                if not is_join and num_of_relations_to_visit > 0:
                     reference_points.append(r1)
 
         return reference_points
